@@ -50,7 +50,6 @@ extern "C"
 
 // KDE includes.
 
-#include <klocale.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
 
@@ -277,12 +276,11 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
         return false;
 
     // Try to get camera maker/model using dcraw with options:
-    // -c : write to stdout
     // -i : identify files without decoding them.
     // -v : verbose mode.
 
     command  = DcrawBinary::path();
-    command += " -c -i -v ";
+    command += " -i -v ";
     command += QFile::encodeName( KProcess::quote( path ) );
     qDebug("Running RAW decoding command: %s", (const char*)command);
 
@@ -353,6 +351,16 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
         identify.model = model;
     }
 
+    // Extract Picture Owner.
+    QString ownerHeader("Owner: ");
+    pos = dcrawInfo.find(ownerHeader);
+    if (pos != -1)
+    {
+        QString owner = dcrawInfo.mid(pos).section('\n', 0, 0);
+        owner.remove(0, ownerHeader.length());
+        identify.owner = owner;
+    }
+
     // Extract DNG Version.
     QString DNGVersionHeader("DNG Version: ");
     pos = dcrawInfo.find(DNGVersionHeader);
@@ -436,19 +444,12 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
             identify.hasIccProfile = false;
     }
 
-    // Extract "Is Decodable" flag.
+    // Check if picture is decodable.
 
-    QString isDecodableHeader("Decodable with dcraw: ");
-    pos = dcrawInfo.find(isDecodableHeader);
+    identify.isDecodable = true;
+    pos = dcrawInfo.find("Cannot decode file");
     if (pos != -1)
-    {
-        QString isDecodable = dcrawInfo.mid(pos).section('\n', 0, 0);
-        isDecodable.remove(0, isDecodableHeader.length());
-        if (isDecodable.contains("yes"))
-            identify.isDecodable = true;
-        else
-            identify.isDecodable = false;
-    }
+        identify.isDecodable = false;
 
     // Extract "Has Secondary Pixel" flag.
 
@@ -712,6 +713,7 @@ void KDcraw::startProcess()
     // -b : set Brightness value.
     // -k : set Black Point value.
     // -r : set Raw Color Balance Multipliers.
+    // -C : set Correct chromatic aberration correction.
 
     *d->process << DcrawBinary::path();
     *d->process << "-c";
@@ -765,6 +767,13 @@ void KDcraw::startProcess()
         *d->process << QString::number(m_rawDecodingSettings.NRThreshold);
     }
 
+    if (m_rawDecodingSettings.enableCACorrection)
+    {
+        *d->process << "-C";
+        *d->process << QString::number(m_rawDecodingSettings.caMultiplier[0], 'f', 5);
+        *d->process << QString::number(m_rawDecodingSettings.caMultiplier[1], 'f', 5);
+    }
+
     *d->process << "-o";
     *d->process << QString::number(m_rawDecodingSettings.outputColorSpace);
 
